@@ -414,3 +414,6 @@ UPPER_CASE = {
 CHARACTERES = tuple(set([*A, *E, *I, *O, *U, *C, *LOWER_CASE, *UPPER_CASE, SPACE]))
 UPPER_CASE_CHARACTERES = tuple(set([char for char in CHARACTERES if char == char.upper() and char == char.strip()]))
 ALL_SYMBOLS = tuple(set([*CHARACTERES, *SYMBOLS, *PUNCTUATION, *NUMBERS]))
+
+OPEN_QUOTES = '“'
+CLOSE_QUOTES = '”'
\ No newline at end of file
