@@ -360,4 +360,71 @@ def minusYears() :
     assert DateTimeHelper.minusYears(
         DateTimeHelper.of(dateTime = '2022-09-10 10:10:10.999'),
         years=2
-    ) == DateTimeHelper.of(dateTime = '2020-09-10 10:10:10.999'), f'2022-09-10 10:10:10.999 - 2 year == 2020-09-10 10:10:10.999'
\ No newline at end of file
+    ) == DateTimeHelper.of(dateTime = '2020-09-10 10:10:10.999'), f'2022-09-10 10:10:10.999 - 2 year == 2020-09-10 10:10:10.999'
+
+
+@Test()
+def isNativeDateTime():
+    #arrange
+    isDateTimeAsString = '2022-09-10 10:10:10.999'
+    isDateAsDateTime = DateTimeHelper.of(isDateTimeAsString)
+
+    #act
+    isDateTimeAsStringToAssert = DateTimeHelper.isNativeDateTime(isDateTimeAsString)
+    isDateAsDateTimeToAssert = DateTimeHelper.isNativeDateTime(isDateAsDateTime)
+
+    #assert
+    assert not isDateTimeAsStringToAssert
+    assert isDateAsDateTimeToAssert
+    assert not DateTimeHelper.isNativeDateTime('2020-02-10 10:09:10.999')
+    assert DateTimeHelper.isNativeDateTime(DateTimeHelper.of('2020-02-10 10:09:10.999'))
+    assert False == DateTimeHelper.isNativeDateTime('abcd'), 'abcd is not date time'
+    assert False == DateTimeHelper.isNativeDateTime(None), f'{None} is not date time'
+    assert False == DateTimeHelper.isNativeDateTime((1,)), f'{(1,)} is not date time'
+    assert False == DateTimeHelper.isNativeDateTime(list()), f'{list()} is not date time'
+    assert False == DateTimeHelper.isNativeDateTime(set()), f'{set()} is not date time'
+    assert False == DateTimeHelper.isNativeDateTime(dict()), f'{dict()} is not date time'
+    assert False == DateTimeHelper.isNativeDateTime(1), f'{1} is not date time'
+    assert False == DateTimeHelper.isNativeDateTime(1.0), f'{1.0} is not date time'
+    assert False == DateTimeHelper.isNativeDateTime(True), f'{True} is not date time'
+    assert False == DateTimeHelper.isNativeDateTime(False), f'{False} is not date time'
+
+
+@Test()
+def isDateTime():
+    #arrange
+    isDateTimeAsString = '2022-09-10 10:10:10.999'
+    isDateAsDateTime = DateTimeHelper.of(isDateTimeAsString)
+
+    #act
+    isDateTimeAsStringToAssert = DateTimeHelper.isDateTime(isDateTimeAsString)
+    isDateAsDateTimeToAssert = DateTimeHelper.isDateTime(isDateAsDateTime)
+
+    #assert
+    assert True == isDateTimeAsStringToAssert
+    assert True == isDateAsDateTimeToAssert
+    assert DateTimeHelper.isDateTime('2020-02-10 10:09:10.999')
+    assert DateTimeHelper.isDateTime(DateTimeHelper.of('2020-02-10 10:09:10.999'))
+    assert False == DateTimeHelper.isDateTime('abcd'), 'abcd is not date time'
+    assert False == DateTimeHelper.isDateTime(None), f'{None} is not date time'
+    assert False == DateTimeHelper.isDateTime((1,)), f'{(1,)} is not date time'
+    assert False == DateTimeHelper.isDateTime(list()), f'{list()} is not date time'
+    assert False == DateTimeHelper.isDateTime(set()), f'{set()} is not date time'
+    assert False == DateTimeHelper.isDateTime(dict()), f'{dict()} is not date time'
+    assert False == DateTimeHelper.isDateTime(1), f'{1} is not date time'
+    assert False == DateTimeHelper.isDateTime(1.0), f'{1.0} is not date time'
+    assert False == DateTimeHelper.isDateTime(True), f'{True} is not date time'
+    assert False == DateTimeHelper.isDateTime(False), f'{False} is not date time'
+
+
+@Test()
+def plusMonths_when_2023_01_31():
+    #arrange
+    dateTimeAsString = DateTimeHelper.of('2023-01-31 10:10:10.999')
+    expected = DateTimeHelper.of('2023-02-28 10:10:10.999')
+
+    #act
+    toAssert = DateTimeHelper.plusMonths(dateTimeAsString, months=1)
+
+    #assert
+    assert ObjectHelper.equals(expected, toAssert), f'{expected} == {toAssert}'
\ No newline at end of file
